@@ -32,7 +32,7 @@ def draw_represent(path, K, max_value=1000, save=False):
         If save is True, saving the representation map image displayed on the screen as a png file in the path
     """
     list_represent = os.listdir(path)
-    for rep in list_represent:s
+    for rep in list_represent:
         try:
             plt.clf()
             heat = np.load(path + rep)
